@@ -57,20 +57,21 @@
 **  can incorporate them into new versions.
 */
 
-#include "config_ac.h"
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
-#else
+#else /* HAVE_STRINGS_H */
 #include <string.h>
-#endif
+#endif /* HAVE_STRINGS_H */
 #include <sys/stat.h>
 #include <math.h>
 
 #include "gfont_gd.h"
 #include "gfont_gdfontl.h"
+#include "lib/xalloc.h"
 
 #define costScale 1024
 int cost[] = {
@@ -144,15 +145,15 @@ gdImagePtr gdImageCreate(int sx, int sy)
 {
     int i;
     gdImagePtr im;
-    im = (gdImage *) malloc(sizeof(gdImage));
-    im->pixels = (unsigned char **) malloc(sizeof(unsigned char *) * sx);
+    im = (gdImage *) xmalloc(sizeof(gdImage));
+    im->pixels = (unsigned char **) xmalloc(sizeof(unsigned char *) * sx);
     im->polyInts = 0;
     im->polyAllocated = 0;
     im->brush = 0;
     im->tile = 0;
     im->style = 0;
     for (i=0; (i<sx); i++) {
-        im->pixels[i] = (unsigned char *) calloc(
+        im->pixels[i] = (unsigned char *) xcalloc(
             sy, sizeof(unsigned char));
     }   
     im->sx = sx;
@@ -549,7 +550,7 @@ int gdImageBoundsSafe(gdImagePtr im, int x, int y)
         ((x < 0) || (x >= im->sx))));
 }
 
-void gdImageChar(gdImagePtr im, gdFontPtr f, int x, int y, int c, int color)
+void gdImageChar(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char c, int color)
 {
     int cx, cy;
     int px, py;
@@ -572,7 +573,7 @@ void gdImageChar(gdImagePtr im, gdFontPtr f, int x, int y, int c, int color)
     }
 }
 
-void gdImageCharUp(gdImagePtr im, gdFontPtr f, int x, int y, char c, int color)
+void gdImageCharUp(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char c, int color)
 {
     int cx, cy;
     int px, py;
@@ -596,7 +597,7 @@ void gdImageCharUp(gdImagePtr im, gdFontPtr f, int x, int y, char c, int color)
 }
 
 #if 0
-void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, char *s, int color)
+void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s, int color)
 {
     int i;
     int l;
@@ -609,7 +610,7 @@ void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, char *s, int color)
 #endif
 
 #if 0
-void gdImageStringUp(gdImagePtr im, gdFontPtr f, int x, int y, char *s, int color)
+void gdImageStringUp(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s, int color)
 {
     int i;
     int l;
@@ -2169,9 +2170,9 @@ void gdImageCopyResized(gdImagePtr dst, gdImagePtr src, int dstX, int dstY, int
     /* We only need to use floating point to determine the correct
         stretch vector for one line's worth. */
     double accum;
-    stx = (int *) malloc(sizeof(int) * srcW);
-    sty = (int *) malloc(sizeof(int) * srcH);
-    accum = 0;
+    stx = (int *) xmalloc(sizeof(int) * srcW);
+    sty = (int *) xmalloc(sizeof(int) * srcH);
+    accum = 0.;
     for (i=0; (i < srcW); i++) {
         int got;
         accum += (double)dstW/(double)srcW;
@@ -2490,14 +2491,14 @@ void gdImageFilledPolygon(gdImagePtr im, gdPointPtr p, int n, int c)
         return;
     }
     if (!im->polyAllocated) {
-        im->polyInts = (int *) malloc(sizeof(int) * n);
+        im->polyInts = (int *) xmalloc(sizeof(int) * n);
         im->polyAllocated = n;
     }       
     if (im->polyAllocated < n) {
         while (im->polyAllocated < n) {
             im->polyAllocated *= 2;
         }   
-        im->polyInts = (int *) realloc(im->polyInts,
+        im->polyInts = (int *) xrealloc(im->polyInts,
             sizeof(int) * im->polyAllocated);
     }
     y1 = p[0].y;
@@ -2606,7 +2607,7 @@ void gdImageSetStyle(gdImagePtr im, int *style, int noOfPixels)
         free(im->style);
     }
     im->style = (int *) 
-        malloc(sizeof(int) * noOfPixels);
+        xmalloc(sizeof(int) * noOfPixels);
     memcpy(im->style, style, sizeof(int) * noOfPixels);
     im->styleLength = noOfPixels;
     im->stylePos = 0;
@@ -2674,40 +2675,18 @@ void gdImageInterlace(gdImagePtr im, int interlaceArg)
 /*****************/
 
 /*
- *  Byte Conversion -- Hilfsroutinen fuer das alte
- *  Problem High-Endian vs. Little-Endian !!
+ *  Byte Conversion
  */
-unsigned short gdIntern_convert_short(unsigned short z)
-{
-    char *teststring;
-    short t;
-
-    t = 0x4142;
-
-    teststring = (char *)&t;
-
-    if(teststring[0] == 'B' && teststring[1] == 'A')
-        return(z);
-    else
-        return(((z & 0xff00U) >> 8) | ((z & 0x00ffU) << 8));
-}
 unsigned long gdIntern_convert_long(unsigned long z)
 {
-    char *teststring;
-    unsigned long t;
-
-    t = 0x41424344;
-
-    teststring = (char *)&t;
-
-    if(teststring[0] == 'D' && teststring[1] == 'C' &&
-       teststring[2] == 'B' && teststring[3] == 'A')
-        return(z);
-    else
-        return(((z & 0xff000000L) >> 24) | 
-               ((z & 0x00ff0000L) >>  8) |
-               ((z & 0x0000ff00L) <<  8) |
-               ((z & 0x000000ffL) << 24));
+#ifndef WORDS_BIGENDIAN /* { */
+    return(z);
+#else /* }{ */
+    return(((z & 0xff000000L) >> 24) | 
+           ((z & 0x00ff0000L) >>  8) |
+           ((z & 0x0000ff00L) <<  8) |
+           ((z & 0x000000ffL) << 24));
+#endif /* } */
 }
 
 gdFontPtr gdFontCreateFromGdf(FILE *in)
@@ -2716,7 +2695,7 @@ gdFontPtr gdFontCreateFromGdf(FILE *in)
     unsigned int int32[10];
     unsigned long i;
 
-    if ((pFont = malloc(sizeof(gdFont))) == NULL)
+    if ((pFont = xmalloc(sizeof(gdFont))) == NULL)
         return(NULL);
     pFont->name = NULL;
 
@@ -2727,14 +2706,14 @@ gdFontPtr gdFontCreateFromGdf(FILE *in)
     pFont->w = gdIntern_convert_long(int32[3]);
     pFont->h = gdIntern_convert_long(int32[4]);
 
-    if ((pFont->width = malloc(sizeof(unsigned int)*pFont->nchars)) == NULL)
+    if ((pFont->width = xmalloc(sizeof(unsigned int)*pFont->nchars)) == NULL)
         return(NULL);
     if (fread(pFont->width, sizeof(unsigned int), pFont->nchars, in) == 0)
         return(NULL);
 
     for(i = 0;i<pFont->nchars;i++) pFont->width[i] = gdIntern_convert_long(pFont->width[i]);
 
-    if ((pFont->data = malloc(sizeof(char)*pFont->w*pFont->h*pFont->nchars)) == NULL)
+    if ((pFont->data = xmalloc(sizeof(char)*pFont->w*pFont->h*pFont->nchars)) == NULL)
         return(NULL);
     if (fread(pFont->data, sizeof(char), pFont->w*pFont->h*pFont->nchars, in) == 0)
         return(NULL);
@@ -2750,7 +2729,7 @@ gdFontPtr gdFontCreateFromGdfFile(char *filename)
     char cmd[1024];
     gdFontPtr pFont;
 
-    if ((cp = rindex(filename, '.')) != NULL) {
+    if ((cp = strrchr(filename, '.')) != NULL) {
         if (strcmp(cp+1, "gz") == 0) {
             gzipped = 1;
         }
@@ -2811,8 +2790,8 @@ unsigned char gd_make_entry_fonttable(char *name, gdFontPtr FontPtr)
         }
         anz_eintraege = akt;
     }
-    FontTable = (FontEntry **) realloc(FontTable,(anz_eintraege+2) * sizeof(FontEntry *));
-    FontTable[anz_eintraege]           = (FontEntry *) malloc(sizeof(FontEntry));
+    FontTable = (FontEntry **) xrealloc(FontTable,(anz_eintraege+2) * sizeof(FontEntry *));
+    FontTable[anz_eintraege]           = (FontEntry *) xmalloc(sizeof(FontEntry));
     FontTable[anz_eintraege]->FontName = strdup(name);
     FontTable[anz_eintraege]->FontPtr  = FontPtr;
     FontTable[anz_eintraege+1]         = NULL;
@@ -2876,7 +2855,7 @@ gdFontPtr *gdFontLoadList(char *fontname[])
 
     for (i = 0; fontname[i] != NULL; i++)
         ;
-    list = (gdFontPtr *)malloc(sizeof(gdFontPtr)*(i+2));
+    list = (gdFontPtr *)xmalloc(sizeof(gdFontPtr)*(i+2));
     for (i = 0, j = 0; fontname[i] != NULL; i++) {
         fp = gdFontLoad(fontname[i]);
         if (fp != NULL) {
@@ -2931,42 +2910,7 @@ void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s, i
         /* non proportional font */
         for (i=0; (i<l); i++) 
             {
-            if(s[i] == 0xdf)            /* scharfes 's'     */
-                gdImageChar(im, f, x, y, 0x19, color);    
-            else if(s[i] == 0xe4)       /* Umlaut 'a'       */
-                { 
-                gdImageChar(im, f, x, y, 0x61, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else if(s[i] == 0xc4)       /* Umlaut 'A'       */
-                { 
-                gdImageChar(im, f, x, y, 0x41, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else if(s[i] == 0xf6)       /* Umlaut 'o'       */
-                { 
-                gdImageChar(im, f, x, y, 0x6f, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else if(s[i] == 0xd6)       /* Umlaut 'O'       */
-                { 
-                gdImageChar(im, f, x, y, 0x4f, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else if(s[i] == 0xfc)       /* Umlaut 'u'       */
-                { 
-                gdImageChar(im, f, x, y, 0x75, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else if(s[i] == 0xdc)       /* Umlaut 'U'       */
-                { 
-                gdImageChar(im, f, x, y, 0x55, color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                }
-            else                        /* normales Zeichen */
-                {
-                gdImageChar(im, f, x, y, s[i], color);
-                }
+            gdImageChar(im, f, x, y, s[i], color);
             x += f->w;
             }
     }
@@ -2977,48 +2921,7 @@ void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s, i
                 {
                 x += (f->width)['-'];
                 }
-            else if(s[i] == 0xdf)            /* scharfes 's'     */
-                {
-                gdImageChar(im, f, x, y, 0x19, color);
-                x += (f->width)[0x19];
-                }    
-            else if(s[i] == 0xe4)       /* Umlaut 'a'       */
-                { 
-                gdImageChar(im, f, x, y, 'a' , color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['a'];
-                }
-            else if(s[i] == 0xc4)       /* Umlaut 'A'       */
-                { 
-                gdImageChar(im, f, x, y, 'A', color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['A'];
-                }
-            else if(s[i] == 0xf6)       /* Umlaut 'o'       */
-                { 
-                gdImageChar(im, f, x, y, 'o' , color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['o'];
-                }
-            else if(s[i] == 0xd6)       /* Umlaut 'O'       */
-                { 
-                gdImageChar(im, f, x, y, 'O' , color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['O'];
-                }
-            else if(s[i] == 0xfc)       /* Umlaut 'u'       */
-                { 
-                gdImageChar(im, f, x, y, 'u' , color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['u'];
-                }
-            else if(s[i] == 0xdc)       /* Umlaut 'U'       */
-                { 
-                gdImageChar(im, f, x, y, 'U' , color); 
-                gdImageChar(im, f, x, y, 0x7f, color);
-                x += (f->width)['U'];
-                }
-            else                        /* normales Zeichen */
+            else
                 {
                 gdImageChar(im, f, x, y, s[i], color);
                 x += (f->width)[s[i]];
@@ -3028,7 +2931,7 @@ void gdImageString(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s, i
     return;
 }
 
-int gdImageStringWidth(gdFontPtr f, char *s)
+int gdImageStringWidth(gdFontPtr f, unsigned char *s)
 {
     int i, l;
     int w;
@@ -3062,48 +2965,7 @@ void gdImageStringUp(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *s,
     for (i=0; (i<l); i++) {
         if(s[i] == ' ') 
             zeichen[0] = 0x20;
-        else if(s[i] == 0xdf)            /* scharfes 's'     */
-            {
-            gdImageCharUp(im, f, x, y, 0x19, color);
-            zeichen[0] = 0x19;
-            }    
-        else if(s[i] == 0xe4)       /* Umlaut 'a'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'a' , color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'a';
-            }
-        else if(s[i] == 0xc4)       /* Umlaut 'A'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'A', color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'A';
-            }
-        else if(s[i] == 0xf6)       /* Umlaut 'o'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'o' , color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'o';
-            }
-        else if(s[i] == 0xd6)       /* Umlaut 'O'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'O' , color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'O';
-            }
-        else if(s[i] == 0xfc)       /* Umlaut 'u'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'u' , color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'u';
-            }
-        else if(s[i] == 0xdc)       /* Umlaut 'U'       */
-            { 
-            gdImageCharUp(im, f, x, y, 'U' , color); 
-            gdImageCharUp(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'U';
-            }
-        else                        /* normales Zeichen */
+        else
             {
             gdImageCharUp(im, f, x, y, s[i], color);
             zeichen[0] = s[i];
@@ -3123,48 +2985,7 @@ void gdImageStringDown(gdImagePtr im, gdFontPtr f, int x, int y, unsigned char *
     for (i=0; i<l; i++) {
         if(s[i] == ' ') 
             zeichen[0] = 0x20;
-        else if(s[i] == 0xdf)            /* scharfes 's'     */
-            {
-            gdImageCharDown(im, f, x, y, 0x19, color);
-            zeichen[0] = 0x19;
-            }    
-        else if(s[i] == 0xe4)       /* Umlaut 'a'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'a' , color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'a';
-            }
-        else if(s[i] == 0xc4)       /* Umlaut 'A'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'A', color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'A';
-            }
-        else if(s[i] == 0xf6)       /* Umlaut 'o'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'o' , color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'o';
-            }
-        else if(s[i] == 0xd6)       /* Umlaut 'O'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'O' , color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'O';
-            }
-        else if(s[i] == 0xfc)       /* Umlaut 'u'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'u' , color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'u';
-            }
-        else if(s[i] == 0xdc)       /* Umlaut 'U'       */
-            { 
-            gdImageCharDown(im, f, x, y, 'U' , color); 
-            gdImageCharDown(im, f, x, y, 0x7f, color);
-            zeichen[0] = 'U';
-            }
-        else                        /* normales Zeichen */
+        else
             {
             gdImageCharDown(im, f, x, y, s[i], color);
             zeichen[0] = s[i];
