@@ -65,6 +65,8 @@
 #endif
 
 #include "gfont_getopt.h"
+#include "gfont_gd.h"
+#include "lib/xalloc.h"
 
 #if !defined (__STDC__) || !__STDC__
 /* This is a separate conditional since some stdc systems
@@ -106,10 +108,12 @@
 
 #ifdef VMS
 #include <unixlib.h>
-#if HAVE_STRING_H - 0
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#else /* HAVE_STRINGS_H */
 #include <string.h>
-#endif
-#endif
+#endif /* HAVE_STRINGS_H */
+#endif /* VMS */
 
 #if defined (WIN32) && !defined (__CYGWIN32__)
 /* It's not Unix, really.  See?  Capital letters.  */
@@ -354,7 +358,7 @@ exchange (argv)
     {
       /* We must extend the array.  The user plays games with us and
          presents new arguments.  */
-      char *new_str = malloc (top + 1);
+      char *new_str = xmalloc (top + 1);
       if (new_str == NULL)
         nonoption_flags_len = nonoption_flags_max_len = 0;
       else
@@ -466,7 +470,7 @@ _getopt_initialize (argc, argv, optstring)
               if (nonoption_flags_max_len < argc)
                 nonoption_flags_max_len = argc;
               __getopt_nonoption_flags =
-                (char *) malloc (nonoption_flags_max_len);
+                (char *) xmalloc (nonoption_flags_max_len);
               if (__getopt_nonoption_flags == NULL)
                 nonoption_flags_max_len = -1;
               else
