@@ -2,20 +2,19 @@
 eval 'exec @PATH_PERL@ -S $0 ${1+"$@"}'
     if $running_under_some_shell;
 ##
-##  mkgdf_pre -- Pregenerate GdF Files from Fontmap
+##  gfont_mkgdf_all -- Pregenerate all GdF Files from Fontmap
 ##  Copyright (c) 1997 Ralf S. Engelschall, <rse@engelschall.com>
 ##
 
 require 5.003;
 use strict;
 
-use vars qw($mkgdf $fontmap $gdfdir $tmpgdfdir);
-use vars qw(@FONT, $font);
+use vars qw($gfontpath $mkgdf $fontmap);
+use vars qw(@FONT $font);
 
-$mkgdf     = "@libdir@@libsubdir@/exec/gfont_mkgdf";
-$fontmap   = "@libdir@@libsubdir@/etc/Fontmap";
-$gdfdir    = "@libdir@@libsubdir@/gdf";
-$tmpgdfdir = "@tmpgdfdir@";
+$gfontpath = $ENV{'GFONT_BASE'} || "@libdir@@libsubdir@";
+$mkgdf     = "$gfontpath/exec/gfont_mkgdf";
+$fontmap   = "$gfontpath/etc/Fontmap";
 
 sub system {
     my ($cmd) = @_;
@@ -27,9 +26,9 @@ sub system {
 @main::FONT = ();
 open(FP, "<$fontmap");
 while (<FP>) {
-    next if (m|^\s*#.+|);
-    next if (m|^\s+$|);
-    if (m|^(\S+)\s+\S+\s*\n?$|) {
+    next if (m|^\s*#|);
+    next if (m|^\s*$|);
+    if (m|^(\S+)\s|) {
         push(@main::FONT, $1);
     }
 }
